@@ -45,12 +45,17 @@ public class Searduino
     public  native String getSearduinoName();
     public  native String getBoardName();
     public  native int    setBoardName(String board);
+    public  native int    setUpBoard();
+    public  native String getBoardSetup();
     public  native int    getNrOfPins();
+    public  native int    getBoardPins(String board);
+    public  native String getSupportedBoards();
 
     public  native int getDigitalMode(int pin);
     public  native int setArduinoCodeName(String ac);
     public  native int getCurrentPinType(int pin);
     public  native int hasGenericPinType(int pin, int type);
+    public  native String getSystemInformation();
     private native int registerPinCallback(SearduinoObserver o, int type);
 
     public native  int fakeAnalogInput(int pin, int val);
@@ -92,6 +97,10 @@ public class Searduino
 
     public static int getPinType(String pintype) 
     {
+	if (pintype==null) {
+	    return -1;
+	}
+
 	if (pintype.equals(SEARDUINO_PINTYPE_DIGITAL_STRING)) 
 	    return SEARDUINO_PINTYPE_DIGITAL;
 	if (pintype.equals(SEARDUINO_PINTYPE_ANALOG_STRING)) 
